# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/judge.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import annotations_pb2 as eolymp_dot_annotations_dot_annotations__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.judge import contest_pb2 as eolymp_dot_judge_dot_contest__pb2
from eolymp.judge import participant_pb2 as eolymp_dot_judge_dot_participant__pb2
from eolymp.judge import problem_pb2 as eolymp_dot_judge_dot_problem__pb2
from eolymp.judge import submission_pb2 as eolymp_dot_judge_dot_submission__pb2
from eolymp.judge import ticket_pb2 as eolymp_dot_judge_dot_ticket__pb2
from eolymp.judge import reply_pb2 as eolymp_dot_judge_dot_reply__pb2
from eolymp.judge import form_pb2 as eolymp_dot_judge_dot_form__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/judge.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x65olymp/judge/judge.proto\x12\x0c\x65olymp.judge\x1a$eolymp/annotations/annotations.proto\x1a!eolymp/wellknown/expression.proto\x1a eolymp/wellknown/direction.proto\x1a\x1a\x65olymp/judge/contest.proto\x1a\x1e\x65olymp/judge/participant.proto\x1a\x1a\x65olymp/judge/problem.proto\x1a\x1d\x65olymp/judge/submission.proto\x1a\x19\x65olymp/judge/ticket.proto\x1a\x18\x65olymp/judge/reply.proto\x1a\x17\x65olymp/judge/form.proto\"<\n\x12\x43reateContestInput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\")\n\x13\x43reateContestOutput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"(\n\x12\x44\x65leteContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteContestOutput\"P\n\x12UpdateContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12&\n\x07\x63ontest\x18\x02 \x01(\x0b\x32\x15.eolymp.judge.Contest\"\x15\n\x13UpdateContestOutput\"*\n\x14\x44\x65scribeContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"?\n\x15\x44\x65scribeContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\"!\n\x12LookupContestInput\x12\x0b\n\x03key\x18\x01 \x01(\t\"=\n\x13LookupContestOutput\x12&\n\x07\x63ontest\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Contest\"\xa6\x03\n\x11ListContestsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.judge.ListContestsInput.Filter\x1a\xb9\x02\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12-\n\x03own\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x38\n\tstarts_at\x18\x04 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x36\n\x07\x65nds_at\x18\x05 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x30\n\x06public\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"I\n\x12ListContestsOutput\x12$\n\x05items\x18\x01 \x03(\x0b\x32\x15.eolymp.judge.Contest\x12\r\n\x05total\x18\x02 \x01(\x05\"&\n\x10OpenContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x13\n\x11OpenContestOutput\"\'\n\x11\x43loseContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12\x43loseContestOutput\"\'\n\x11StartContestInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x14\n\x12StartContestOutput\"P\n\x12\x43reateProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12&\n\x07problem\x18\x02 \x01(\x0b\x32\x15.eolymp.judge.Problem\")\n\x13\x43reateProblemOutput\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"Y\n\x12ImportProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\timport_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\n \x01(\x05\x12\r\n\x05score\x18\x0b \x01(\x05\")\n\x13ImportProblemOutput\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"&\n\x10SyncProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x13\n\x11SyncProblemOutput\"(\n\x12\x44\x65leteProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteProblemOutput\"(\n\x12RetestProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"\x15\n\x13RetestProblemOutput\"\xd1\x01\n\x11ListProblemsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x19\n\x11preferred_locales\x18\x14 \x03(\t\x12\x15\n\ronly_examples\x18\x15 \x01(\x08\x12\x15\n\rwith_verifier\x18\x1e \x01(\x08\x12\x17\n\x0fwith_statements\x18\x1f \x01(\x08\x12\x14\n\x0cwith_content\x18  \x01(\x08\x12\x12\n\nwith_tests\x18! \x01(\x08\"I\n\x12ListProblemsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.judge.Problem\"\xb6\x01\n\x14\x44\x65scribeProblemInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x19\n\x11preferred_locales\x18\n \x03(\t\x12\x15\n\ronly_examples\x18\x0b \x01(\x08\x12\x15\n\rwith_verifier\x18\x14 \x01(\x08\x12\x17\n\x0fwith_statements\x18\x15 \x01(\x08\x12\x14\n\x0cwith_content\x18\x16 \x01(\x08\x12\x12\n\nwith_tests\x18\x17 \x01(\x08\"?\n\x15\x44\x65scribeProblemOutput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Problem\":\n\x13\x41\x64\x64ParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\".\n\x14\x41\x64\x64ParticipantOutput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"0\n\x16RemoveParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"\x19\n\x17RemoveParticipantOutput\"\xc1\x05\n\x15ListParticipantsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.judge.ListParticipantsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.judge.ListParticipantsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xf4\x02\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x04 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x32\n\x07penalty\x18\x05 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x39\n\nstarted_at\x18\x06 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12:\n\x0b\x63omplete_at\x18\x07 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"Z\n\x08Sortable\x12\x08\n\x04RANK\x10\x00\x12\t\n\x05SCORE\x10\x01\x12\x0b\n\x07PENALTY\x10\x02\x12\x0b\n\x07USER_ID\x10\x03\x12\x0e\n\nSTARTED_AT\x10\x04\x12\x0f\n\x0b\x43OMPLETE_AT\x10\x05\"Q\n\x16ListParticipantsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.judge.Participant\"0\n\x1aIntrospectParticipantInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"M\n\x1bIntrospectParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"2\n\x18\x44\x65scribeParticipantInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"K\n\x19\x44\x65scribeParticipantOutput\x12.\n\x0bparticipant\x18\x01 \x01(\x0b\x32\x19.eolymp.judge.Participant\"I\n\x15\x43reateSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\xa4\x04\n\x14ListSubmissionsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x03 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.judge.ListSubmissionsInput.Filter\x1a\xf1\x02\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\nproblem_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12.\n\x04lang\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x06 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12;\n\x0csubmitted_at\x18\x07 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"O\n\x15ListSubmissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.judge.Submission\"0\n\x17\x44\x65scribeSubmissionInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"H\n\x18\x44\x65scribeSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\".\n\x15RetestSubmissionInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\x18\n\x16RetestSubmissionOutput\"I\n\x11\x43reateTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\'\n\x12\x43reateTicketOutput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"%\n\x10\x43loseTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x13\n\x11\x43loseTicketOutput\"$\n\x0fOpenTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x12\n\x10OpenTicketOutput\"$\n\x0fReadTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x12\n\x10ReadTicketOutput\"&\n\x11\x44\x65leteTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteTicketOutput\"(\n\x13\x44\x65scribeTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"<\n\x14\x44\x65scribeTicketOutput\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"\xd7\x03\n\x10ListTicketsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.judge.ListTicketsInput.Filter\x1a\xec\x02\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncontest_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\x07is_read\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x35\n\x0bneeds_reply\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x31\n\x07is_open\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12-\n\x03own\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"G\n\x11ListTicketsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Ticket\"E\n\x10ReplyTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x15 \x01(\x08\"%\n\x11ReplyTicketOutput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"C\n\x10ListRepliesInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"F\n\x11ListRepliesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.eolymp.judge.Reply\"$\n\x10\x44\x65leteReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteReplyOutput\"5\n\x10UpdateReplyInput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x13\n\x11UpdateReplyOutput\"V\n\x1e\x43onfigureRegistrationFormInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12 \n\x04\x66orm\x18\n \x01(\x0b\x32\x12.eolymp.judge.Form\"!\n\x1f\x43onfigureRegistrationFormOutput\"3\n\x1d\x44\x65scribeRegistrationFormInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"B\n\x1e\x44\x65scribeRegistrationFormOutput\x12 \n\x04\x66orm\x18\x01 \x01(\x0b\x32\x12.eolymp.judge.Form\"_\n\x17SubmitRegistrationInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x30\n\x0cregistration\x18\n \x01(\x0b\x32\x1a.eolymp.judge.Registration\"\x1a\n\x18SubmitRegistrationOutput\"3\n\x19\x44\x65scribeRegistrationInput\x12\x16\n\x0eparticipant_id\x18\x01 \x01(\t\"N\n\x1a\x44\x65scribeRegistrationOutput\x12\x30\n\x0cregistration\x18\x01 \x01(\x0b\x32\x1a.eolymp.judge.Registration2\xa5:\n\x05Judge\x12\xa4\x01\n\rCreateContest\x12 .eolymp.judge.CreateContestInput\x1a!.eolymp.judge.CreateContestOutput\"N\x82\xd3\xe4\x93\x02H\"\'/twirp/eolymp.judge.Judge/CreateContest:\x01*Z\x1a\"\x0f/judge/contests:\x07\x63ontest\x12\xa8\x01\n\rDeleteContest\x12 .eolymp.judge.DeleteContestInput\x1a!.eolymp.judge.DeleteContestOutput\"R\x82\xd3\xe4\x93\x02L\"\'/twirp/eolymp.judge.Judge/DeleteContest:\x01*Z\x1e*\x1c/judge/contests/{contest_id}\x12\xb1\x01\n\rUpdateContest\x12 .eolymp.judge.UpdateContestInput\x1a!.eolymp.judge.UpdateContestOutput\"[\x82\xd3\xe4\x93\x02U\"\'/twirp/eolymp.judge.Judge/UpdateContest:\x01*Z\'\x1a\x1c/judge/contests/{contest_id}:\x07\x63ontest\x12\xa2\x01\n\rLookupContest\x12 .eolymp.judge.LookupContestInput\x1a!.eolymp.judge.LookupContestOutput\"L\x82\xd3\xe4\x93\x02\x46\"\'/twirp/eolymp.judge.Judge/LookupContest:\x01*Z\x18\x12\x13/judge/lookup/{key}b\x01*\x12\xb9\x01\n\x0f\x44\x65scribeContest\x12\".eolymp.judge.DescribeContestInput\x1a#.eolymp.judge.DescribeContestOutput\"]\x82\xd3\xe4\x93\x02W\")/twirp/eolymp.judge.Judge/DescribeContest:\x01*Z\'\x12\x1c/judge/contests/{contest_id}b\x07\x63ontest\x12\x97\x01\n\x0cListContests\x12\x1f.eolymp.judge.ListContestsInput\x1a .eolymp.judge.ListContestsOutput\"D\x82\xd3\xe4\x93\x02>\"&/twirp/eolymp.judge.Judge/ListContests:\x01*Z\x11\x12\x0f/judge/contests\x12\xa5\x01\n\x0bOpenContest\x12\x1e.eolymp.judge.OpenContestInput\x1a\x1f.eolymp.judge.OpenContestOutput\"U\x82\xd3\xe4\x93\x02O\"%/twirp/eolymp.judge.Judge/OpenContest:\x01*Z#\"!/judge/contests/{contest_id}/open\x12\xaa\x01\n\x0c\x43loseContest\x12\x1f.eolymp.judge.CloseContestInput\x1a .eolymp.judge.CloseContestOutput\"W\x82\xd3\xe4\x93\x02Q\"&/twirp/eolymp.judge.Judge/CloseContest:\x01*Z$\"\"/judge/contests/{contest_id}/close\x12\xea\x01\n\x19\x43onfigureRegistrationForm\x12,.eolymp.judge.ConfigureRegistrationFormInput\x1a-.eolymp.judge.ConfigureRegistrationFormOutput\"p\x82\xd3\xe4\x93\x02j\"3/twirp/eolymp.judge.Judge/ConfigureRegistrationForm:\x01*Z0\"./judge/contests/{contest_id}/registration-form\x12\xec\x01\n\x18\x44\x65scribeRegistrationForm\x12+.eolymp.judge.DescribeRegistrationFormInput\x1a,.eolymp.judge.DescribeRegistrationFormOutput\"u\x82\xd3\xe4\x93\x02o\"2/twirp/eolymp.judge.Judge/DescribeRegistrationForm:\x01*Z6\x12./judge/contests/{contest_id}/registration-formb\x04\x66orm\x12\xc5\x01\n\x12SubmitRegistration\x12%.eolymp.judge.SubmitRegistrationInput\x1a&.eolymp.judge.SubmitRegistrationOutput\"`\x82\xd3\xe4\x93\x02Z\",/twirp/eolymp.judge.Judge/SubmitRegistration:\x01*Z\'\"%/judge/contests/{contest_id}/register\x12\xd9\x01\n\x14\x44\x65scribeRegistration\x12\'.eolymp.judge.DescribeRegistrationInput\x1a(.eolymp.judge.DescribeRegistrationOutput\"n\x82\xd3\xe4\x93\x02h\"./twirp/eolymp.judge.Judge/DescribeRegistration:\x01*Z3\x12\x31/judge/participants/{participant_id}/registration\x12\xba\x01\n\rCreateProblem\x12 .eolymp.judge.CreateProblemInput\x1a!.eolymp.judge.CreateProblemOutput\"d\x82\xd3\xe4\x93\x02^\"\'/twirp/eolymp.judge.Judge/CreateProblem:\x01*Z0\"%/judge/contests/{contest_id}/problems:\x07problem\x12\xb7\x01\n\rImportProblem\x12 .eolymp.judge.ImportProblemInput\x1a!.eolymp.judge.ImportProblemOutput\"a\x82\xd3\xe4\x93\x02[\"\'/twirp/eolymp.judge.Judge/ImportProblem:\x01*Z-\"+/judge/contests/{contest_id}/import/problem\x12\xa5\x01\n\x0bSyncProblem\x12\x1e.eolymp.judge.SyncProblemInput\x1a\x1f.eolymp.judge.SyncProblemOutput\"U\x82\xd3\xe4\x93\x02O\"%/twirp/eolymp.judge.Judge/SyncProblem:\x01*Z#\"!/judge/problems/{problem_id}/sync\x12\xad\x01\n\x0cListProblems\x12\x1f.eolymp.judge.ListProblemsInput\x1a .eolymp.judge.ListProblemsOutput\"Z\x82\xd3\xe4\x93\x02T\"&/twirp/eolymp.judge.Judge/ListProblems:\x01*Z\'\x12%/judge/contests/{contest_id}/problems\x12\xb0\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.judge.DescribeProblemInput\x1a#.eolymp.judge.DescribeProblemOutput\"T\x82\xd3\xe4\x93\x02N\")/twirp/eolymp.judge.Judge/DescribeProblem:\x01*Z\x1e\x12\x1c/judge/problems/{problem_id}\x12\xa8\x01\n\rDeleteProblem\x12 .eolymp.judge.DeleteProblemInput\x1a!.eolymp.judge.DeleteProblemOutput\"R\x82\xd3\xe4\x93\x02L\"\'/twirp/eolymp.judge.Judge/DeleteProblem:\x01*Z\x1e*\x1c/judge/problems/{problem_id}\x12\xb2\x01\n\rRetestProblem\x12 .eolymp.judge.RetestProblemInput\x1a!.eolymp.judge.RetestProblemOutput\"\\\x82\xd3\xe4\x93\x02V\"\'/twirp/eolymp.judge.Judge/RetestProblem:\x01*Z(\x12#/judge/problems/{problem_id}/retestb\x01*\x12\xbc\x01\n\x0e\x41\x64\x64Participant\x12!.eolymp.judge.AddParticipantInput\x1a\".eolymp.judge.AddParticipantOutput\"c\x82\xd3\xe4\x93\x02]\"(/twirp/eolymp.judge.Judge/AddParticipant:\x01*Z.\")/judge/contests/{contest_id}/participants:\x01*\x12\xc0\x01\n\x11RemoveParticipant\x12$.eolymp.judge.RemoveParticipantInput\x1a%.eolymp.judge.RemoveParticipantOutput\"^\x82\xd3\xe4\x93\x02X\"+/twirp/eolymp.judge.Judge/RemoveParticipant:\x01*Z&*$/judge/participants/{participant_id}\x12\xc1\x01\n\x10ListParticipants\x12#.eolymp.judge.ListParticipantsInput\x1a$.eolymp.judge.ListParticipantsOutput\"b\x82\xd3\xe4\x93\x02\\\"*/twirp/eolymp.judge.Judge/ListParticipants:\x01*Z+\x12)/judge/contests/{contest_id}/participants\x12\xd5\x01\n\x13\x44\x65scribeParticipant\x12&.eolymp.judge.DescribeParticipantInput\x1a\'.eolymp.judge.DescribeParticipantOutput\"m\x82\xd3\xe4\x93\x02g\"-/twirp/eolymp.judge.Judge/DescribeParticipant:\x01*Z3\x12$/judge/participants/{participant_id}b\x0bparticipant\x12\xe0\x01\n\x15IntrospectParticipant\x12(.eolymp.judge.IntrospectParticipantInput\x1a).eolymp.judge.IntrospectParticipantOutput\"r\x82\xd3\xe4\x93\x02l\"//twirp/eolymp.judge.Judge/IntrospectParticipant:\x01*Z6\x12\'/judge/contests/{contest_id}/introspectb\x0bparticipant\x12\xaa\x01\n\x0cStartContest\x12\x1f.eolymp.judge.StartContestInput\x1a .eolymp.judge.StartContestOutput\"W\x82\xd3\xe4\x93\x02Q\"&/twirp/eolymp.judge.Judge/StartContest:\x01*Z$\"\"/judge/contests/{contest_id}/start\x12\xc3\x01\n\x10\x43reateSubmission\x12#.eolymp.judge.CreateSubmissionInput\x1a$.eolymp.judge.CreateSubmissionOutput\"d\x82\xd3\xe4\x93\x02^\"*/twirp/eolymp.judge.Judge/CreateSubmission:\x01*Z-\"(/judge/problems/{problem_id}/submissions:\x01*\x12\x9e\x02\n\x0fListSubmissions\x12\".eolymp.judge.ListSubmissionsInput\x1a#.eolymp.judge.ListSubmissionsOutput\"\xc1\x01\x82\xd3\xe4\x93\x02\xba\x01\")/twirp/eolymp.judge.Judge/ListSubmissions:\x01*Z*\x12(/judge/contests/{contest_id}/submissionsZ*\x12(/judge/problems/{problem_id}/submissionsZ2\x12\x30/judge/participants/{participant_id}/submissions\x12\xce\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.judge.DescribeSubmissionInput\x1a&.eolymp.judge.DescribeSubmissionOutput\"i\x82\xd3\xe4\x93\x02\x63\",/twirp/eolymp.judge.Judge/DescribeSubmission:\x01*Z0\x12\"/judge/submissions/{submission_id}b\nsubmission\x12\xc4\x01\n\x10RetestSubmission\x12#.eolymp.judge.RetestSubmissionInput\x1a$.eolymp.judge.RetestSubmissionOutput\"e\x82\xd3\xe4\x93\x02_\"*/twirp/eolymp.judge.Judge/RetestSubmission:\x01*Z.\x12)/judge/submissions/{submission_id}/retestb\x01*\x12\xaf\x01\n\x0c\x43reateTicket\x12\x1f.eolymp.judge.CreateTicketInput\x1a .eolymp.judge.CreateTicketOutput\"\\\x82\xd3\xe4\x93\x02V\"&/twirp/eolymp.judge.Judge/CreateTicket:\x01*Z)\"$/judge/contests/{contest_id}/ticketsb\x01*\x12\xa7\x01\n\x0b\x43loseTicket\x12\x1e.eolymp.judge.CloseTicketInput\x1a\x1f.eolymp.judge.CloseTicketOutput\"W\x82\xd3\xe4\x93\x02Q\"%/twirp/eolymp.judge.Judge/CloseTicket:\x01*Z%\" /judge/tickets/{ticket_id}/closeb\x01*\x12\xa2\x01\n\nOpenTicket\x12\x1d.eolymp.judge.OpenTicketInput\x1a\x1e.eolymp.judge.OpenTicketOutput\"U\x82\xd3\xe4\x93\x02O\"$/twirp/eolymp.judge.Judge/OpenTicket:\x01*Z$\"\x1f/judge/tickets/{ticket_id}/openb\x01*\x12\xa2\x01\n\nReadTicket\x12\x1d.eolymp.judge.ReadTicketInput\x1a\x1e.eolymp.judge.ReadTicketOutput\"U\x82\xd3\xe4\x93\x02O\"$/twirp/eolymp.judge.Judge/ReadTicket:\x01*Z$\"\x1f/judge/tickets/{ticket_id}/readb\x01*\x12\xa5\x01\n\x0c\x44\x65leteTicket\x12\x1f.eolymp.judge.DeleteTicketInput\x1a .eolymp.judge.DeleteTicketOutput\"R\x82\xd3\xe4\x93\x02L\"&/twirp/eolymp.judge.Judge/DeleteTicket:\x01*Z\x1f*\x1a/judge/tickets/{ticket_id}b\x01*\x12\xb2\x01\n\x0e\x44\x65scribeTicket\x12!.eolymp.judge.DescribeTicketInput\x1a\".eolymp.judge.DescribeTicketOutput\"Y\x82\xd3\xe4\x93\x02S\"(/twirp/eolymp.judge.Judge/DescribeTicket:\x01*Z$\x12\x1a/judge/tickets/{ticket_id}b\x06ticket\x12\x95\x01\n\x0bListTickets\x12\x1e.eolymp.judge.ListTicketsInput\x1a\x1f.eolymp.judge.ListTicketsOutput\"E\x82\xd3\xe4\x93\x02?\"%/twirp/eolymp.judge.Judge/ListTickets:\x01*Z\x13\x12\x0e/judge/ticketsb\x01*\x12\xa9\x01\n\x0bReplyTicket\x12\x1e.eolymp.judge.ReplyTicketInput\x1a\x1f.eolymp.judge.ReplyTicketOutput\"Y\x82\xd3\xe4\x93\x02S\"%/twirp/eolymp.judge.Judge/ReplyTicket:\x01*Z\'\"\"/judge/tickets/{ticket_id}/repliesb\x01*\x12\xa9\x01\n\x0bListReplies\x12\x1e.eolymp.judge.ListRepliesInput\x1a\x1f.eolymp.judge.ListRepliesOutput\"Y\x82\xd3\xe4\x93\x02S\"%/twirp/eolymp.judge.Judge/ListReplies:\x01*Z\'\x12\"/judge/tickets/{ticket_id}/repliesb\x01*\x12\xa0\x01\n\x0b\x44\x65leteReply\x12\x1e.eolymp.judge.DeleteReplyInput\x1a\x1f.eolymp.judge.DeleteReplyOutput\"P\x82\xd3\xe4\x93\x02J\"%/twirp/eolymp.judge.Judge/DeleteReply:\x01*Z\x1e*\x19/judge/replies/{reply_id}b\x01*\x12\xa0\x01\n\x0bUpdateReply\x12\x1e.eolymp.judge.UpdateReplyInput\x1a\x1f.eolymp.judge.UpdateReplyOutput\"P\x82\xd3\xe4\x93\x02J\"%/twirp/eolymp.judge.Judge/UpdateReply:\x01*Z\x1e\"\x19/judge/replies/{reply_id}b\x01*B3Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_annotations__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_direction__pb2.DESCRIPTOR,eolymp_dot_judge_dot_contest__pb2.DESCRIPTOR,eolymp_dot_judge_dot_participant__pb2.DESCRIPTOR,eolymp_dot_judge_dot_problem__pb2.DESCRIPTOR,eolymp_dot_judge_dot_submission__pb2.DESCRIPTOR,eolymp_dot_judge_dot_ticket__pb2.DESCRIPTOR,eolymp_dot_judge_dot_reply__pb2.DESCRIPTOR,eolymp_dot_judge_dot_form__pb2.DESCRIPTOR,])



_LISTPARTICIPANTSINPUT_SORTABLE = _descriptor.EnumDescriptor(
  name='Sortable',
  full_name='eolymp.judge.ListParticipantsInput.Sortable',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RANK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCORE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENALTY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_ID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTED_AT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE_AT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3303,
  serialized_end=3393,
)
_sym_db.RegisterEnumDescriptor(_LISTPARTICIPANTSINPUT_SORTABLE)


_CREATECONTESTINPUT = _descriptor.Descriptor(
  name='CreateContestInput',
  full_name='eolymp.judge.CreateContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest', full_name='eolymp.judge.CreateContestInput.contest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=406,
)


_CREATECONTESTOUTPUT = _descriptor.Descriptor(
  name='CreateContestOutput',
  full_name='eolymp.judge.CreateContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.CreateContestOutput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=408,
  serialized_end=449,
)


_DELETECONTESTINPUT = _descriptor.Descriptor(
  name='DeleteContestInput',
  full_name='eolymp.judge.DeleteContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.DeleteContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=491,
)


_DELETECONTESTOUTPUT = _descriptor.Descriptor(
  name='DeleteContestOutput',
  full_name='eolymp.judge.DeleteContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=514,
)


_UPDATECONTESTINPUT = _descriptor.Descriptor(
  name='UpdateContestInput',
  full_name='eolymp.judge.UpdateContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.UpdateContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest', full_name='eolymp.judge.UpdateContestInput.contest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=516,
  serialized_end=596,
)


_UPDATECONTESTOUTPUT = _descriptor.Descriptor(
  name='UpdateContestOutput',
  full_name='eolymp.judge.UpdateContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=619,
)


_DESCRIBECONTESTINPUT = _descriptor.Descriptor(
  name='DescribeContestInput',
  full_name='eolymp.judge.DescribeContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.DescribeContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=663,
)


_DESCRIBECONTESTOUTPUT = _descriptor.Descriptor(
  name='DescribeContestOutput',
  full_name='eolymp.judge.DescribeContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest', full_name='eolymp.judge.DescribeContestOutput.contest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=728,
)


_LOOKUPCONTESTINPUT = _descriptor.Descriptor(
  name='LookupContestInput',
  full_name='eolymp.judge.LookupContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.judge.LookupContestInput.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=730,
  serialized_end=763,
)


_LOOKUPCONTESTOUTPUT = _descriptor.Descriptor(
  name='LookupContestOutput',
  full_name='eolymp.judge.LookupContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest', full_name='eolymp.judge.LookupContestOutput.contest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=826,
)


_LISTCONTESTSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListContestsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.ListContestsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='own', full_name='eolymp.judge.ListContestsInput.Filter.own', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.judge.ListContestsInput.Filter.name', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='starts_at', full_name='eolymp.judge.ListContestsInput.Filter.starts_at', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ends_at', full_name='eolymp.judge.ListContestsInput.Filter.ends_at', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public', full_name='eolymp.judge.ListContestsInput.Filter.public', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1251,
)

_LISTCONTESTSINPUT = _descriptor.Descriptor(
  name='ListContestsInput',
  full_name='eolymp.judge.ListContestsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListContestsInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListContestsInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListContestsInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTCONTESTSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=1251,
)


_LISTCONTESTSOUTPUT = _descriptor.Descriptor(
  name='ListContestsOutput',
  full_name='eolymp.judge.ListContestsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListContestsOutput.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListContestsOutput.total', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1253,
  serialized_end=1326,
)


_OPENCONTESTINPUT = _descriptor.Descriptor(
  name='OpenContestInput',
  full_name='eolymp.judge.OpenContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.OpenContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1328,
  serialized_end=1366,
)


_OPENCONTESTOUTPUT = _descriptor.Descriptor(
  name='OpenContestOutput',
  full_name='eolymp.judge.OpenContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1368,
  serialized_end=1387,
)


_CLOSECONTESTINPUT = _descriptor.Descriptor(
  name='CloseContestInput',
  full_name='eolymp.judge.CloseContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.CloseContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1389,
  serialized_end=1428,
)


_CLOSECONTESTOUTPUT = _descriptor.Descriptor(
  name='CloseContestOutput',
  full_name='eolymp.judge.CloseContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1430,
  serialized_end=1450,
)


_STARTCONTESTINPUT = _descriptor.Descriptor(
  name='StartContestInput',
  full_name='eolymp.judge.StartContestInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.StartContestInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1452,
  serialized_end=1491,
)


_STARTCONTESTOUTPUT = _descriptor.Descriptor(
  name='StartContestOutput',
  full_name='eolymp.judge.StartContestOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1493,
  serialized_end=1513,
)


_CREATEPROBLEMINPUT = _descriptor.Descriptor(
  name='CreateProblemInput',
  full_name='eolymp.judge.CreateProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.CreateProblemInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem', full_name='eolymp.judge.CreateProblemInput.problem', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1595,
)


_CREATEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='CreateProblemOutput',
  full_name='eolymp.judge.CreateProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.CreateProblemOutput.problem_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1597,
  serialized_end=1638,
)


_IMPORTPROBLEMINPUT = _descriptor.Descriptor(
  name='ImportProblemInput',
  full_name='eolymp.judge.ImportProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ImportProblemInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='import_id', full_name='eolymp.judge.ImportProblemInput.import_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='eolymp.judge.ImportProblemInput.index', index=2,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.ImportProblemInput.score', index=3,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1640,
  serialized_end=1729,
)


_IMPORTPROBLEMOUTPUT = _descriptor.Descriptor(
  name='ImportProblemOutput',
  full_name='eolymp.judge.ImportProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.ImportProblemOutput.problem_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1731,
  serialized_end=1772,
)


_SYNCPROBLEMINPUT = _descriptor.Descriptor(
  name='SyncProblemInput',
  full_name='eolymp.judge.SyncProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.SyncProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1774,
  serialized_end=1812,
)


_SYNCPROBLEMOUTPUT = _descriptor.Descriptor(
  name='SyncProblemOutput',
  full_name='eolymp.judge.SyncProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1814,
  serialized_end=1833,
)


_DELETEPROBLEMINPUT = _descriptor.Descriptor(
  name='DeleteProblemInput',
  full_name='eolymp.judge.DeleteProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.DeleteProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1835,
  serialized_end=1875,
)


_DELETEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='DeleteProblemOutput',
  full_name='eolymp.judge.DeleteProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1877,
  serialized_end=1898,
)


_RETESTPROBLEMINPUT = _descriptor.Descriptor(
  name='RetestProblemInput',
  full_name='eolymp.judge.RetestProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.RetestProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1900,
  serialized_end=1940,
)


_RETESTPROBLEMOUTPUT = _descriptor.Descriptor(
  name='RetestProblemOutput',
  full_name='eolymp.judge.RetestProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1942,
  serialized_end=1963,
)


_LISTPROBLEMSINPUT = _descriptor.Descriptor(
  name='ListProblemsInput',
  full_name='eolymp.judge.ListProblemsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListProblemsInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListProblemsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListProblemsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_locales', full_name='eolymp.judge.ListProblemsInput.preferred_locales', index=3,
      number=20, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_examples', full_name='eolymp.judge.ListProblemsInput.only_examples', index=4,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_verifier', full_name='eolymp.judge.ListProblemsInput.with_verifier', index=5,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_statements', full_name='eolymp.judge.ListProblemsInput.with_statements', index=6,
      number=31, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_content', full_name='eolymp.judge.ListProblemsInput.with_content', index=7,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_tests', full_name='eolymp.judge.ListProblemsInput.with_tests', index=8,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1966,
  serialized_end=2175,
)


_LISTPROBLEMSOUTPUT = _descriptor.Descriptor(
  name='ListProblemsOutput',
  full_name='eolymp.judge.ListProblemsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListProblemsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListProblemsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2177,
  serialized_end=2250,
)


_DESCRIBEPROBLEMINPUT = _descriptor.Descriptor(
  name='DescribeProblemInput',
  full_name='eolymp.judge.DescribeProblemInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.DescribeProblemInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_locales', full_name='eolymp.judge.DescribeProblemInput.preferred_locales', index=1,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_examples', full_name='eolymp.judge.DescribeProblemInput.only_examples', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_verifier', full_name='eolymp.judge.DescribeProblemInput.with_verifier', index=3,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_statements', full_name='eolymp.judge.DescribeProblemInput.with_statements', index=4,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_content', full_name='eolymp.judge.DescribeProblemInput.with_content', index=5,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_tests', full_name='eolymp.judge.DescribeProblemInput.with_tests', index=6,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2253,
  serialized_end=2435,
)


_DESCRIBEPROBLEMOUTPUT = _descriptor.Descriptor(
  name='DescribeProblemOutput',
  full_name='eolymp.judge.DescribeProblemOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem', full_name='eolymp.judge.DescribeProblemOutput.problem', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2437,
  serialized_end=2500,
)


_ADDPARTICIPANTINPUT = _descriptor.Descriptor(
  name='AddParticipantInput',
  full_name='eolymp.judge.AddParticipantInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.AddParticipantInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.judge.AddParticipantInput.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2502,
  serialized_end=2560,
)


_ADDPARTICIPANTOUTPUT = _descriptor.Descriptor(
  name='AddParticipantOutput',
  full_name='eolymp.judge.AddParticipantOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.AddParticipantOutput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2562,
  serialized_end=2608,
)


_REMOVEPARTICIPANTINPUT = _descriptor.Descriptor(
  name='RemoveParticipantInput',
  full_name='eolymp.judge.RemoveParticipantInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.RemoveParticipantInput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2610,
  serialized_end=2658,
)


_REMOVEPARTICIPANTOUTPUT = _descriptor.Descriptor(
  name='RemoveParticipantOutput',
  full_name='eolymp.judge.RemoveParticipantOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2660,
  serialized_end=2685,
)


_LISTPARTICIPANTSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListParticipantsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.ListParticipantsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.judge.ListParticipantsInput.Filter.user_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.ListParticipantsInput.Filter.status', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.ListParticipantsInput.Filter.score', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.judge.ListParticipantsInput.Filter.penalty', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='eolymp.judge.ListParticipantsInput.Filter.started_at', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='complete_at', full_name='eolymp.judge.ListParticipantsInput.Filter.complete_at', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2929,
  serialized_end=3301,
)

_LISTPARTICIPANTSINPUT = _descriptor.Descriptor(
  name='ListParticipantsInput',
  full_name='eolymp.judge.ListParticipantsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListParticipantsInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListParticipantsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListParticipantsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListParticipantsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sort', full_name='eolymp.judge.ListParticipantsInput.sort', index=4,
      number=50, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='eolymp.judge.ListParticipantsInput.order', index=5,
      number=51, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPARTICIPANTSINPUT_FILTER, ],
  enum_types=[
    _LISTPARTICIPANTSINPUT_SORTABLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2688,
  serialized_end=3393,
)


_LISTPARTICIPANTSOUTPUT = _descriptor.Descriptor(
  name='ListParticipantsOutput',
  full_name='eolymp.judge.ListParticipantsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListParticipantsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListParticipantsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3395,
  serialized_end=3476,
)


_INTROSPECTPARTICIPANTINPUT = _descriptor.Descriptor(
  name='IntrospectParticipantInput',
  full_name='eolymp.judge.IntrospectParticipantInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.IntrospectParticipantInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3478,
  serialized_end=3526,
)


_INTROSPECTPARTICIPANTOUTPUT = _descriptor.Descriptor(
  name='IntrospectParticipantOutput',
  full_name='eolymp.judge.IntrospectParticipantOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant', full_name='eolymp.judge.IntrospectParticipantOutput.participant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3528,
  serialized_end=3605,
)


_DESCRIBEPARTICIPANTINPUT = _descriptor.Descriptor(
  name='DescribeParticipantInput',
  full_name='eolymp.judge.DescribeParticipantInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.DescribeParticipantInput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3607,
  serialized_end=3657,
)


_DESCRIBEPARTICIPANTOUTPUT = _descriptor.Descriptor(
  name='DescribeParticipantOutput',
  full_name='eolymp.judge.DescribeParticipantOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant', full_name='eolymp.judge.DescribeParticipantOutput.participant', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3659,
  serialized_end=3734,
)


_CREATESUBMISSIONINPUT = _descriptor.Descriptor(
  name='CreateSubmissionInput',
  full_name='eolymp.judge.CreateSubmissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.CreateSubmissionInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.judge.CreateSubmissionInput.lang', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.judge.CreateSubmissionInput.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3736,
  serialized_end=3809,
)


_CREATESUBMISSIONOUTPUT = _descriptor.Descriptor(
  name='CreateSubmissionOutput',
  full_name='eolymp.judge.CreateSubmissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.judge.CreateSubmissionOutput.submission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3811,
  serialized_end=3858,
)


_LISTSUBMISSIONSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListSubmissionsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.ListSubmissionsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.ListSubmissionsInput.Filter.participant_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.ListSubmissionsInput.Filter.problem_id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.ListSubmissionsInput.Filter.status', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.judge.ListSubmissionsInput.Filter.lang', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.ListSubmissionsInput.Filter.score', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submitted_at', full_name='eolymp.judge.ListSubmissionsInput.Filter.submitted_at', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4040,
  serialized_end=4409,
)

_LISTSUBMISSIONSINPUT = _descriptor.Descriptor(
  name='ListSubmissionsInput',
  full_name='eolymp.judge.ListSubmissionsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListSubmissionsInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.ListSubmissionsInput.problem_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.ListSubmissionsInput.participant_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListSubmissionsInput.offset', index=3,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListSubmissionsInput.size', index=4,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListSubmissionsInput.filters', index=5,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSUBMISSIONSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3861,
  serialized_end=4409,
)


_LISTSUBMISSIONSOUTPUT = _descriptor.Descriptor(
  name='ListSubmissionsOutput',
  full_name='eolymp.judge.ListSubmissionsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListSubmissionsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListSubmissionsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4411,
  serialized_end=4490,
)


_DESCRIBESUBMISSIONINPUT = _descriptor.Descriptor(
  name='DescribeSubmissionInput',
  full_name='eolymp.judge.DescribeSubmissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.judge.DescribeSubmissionInput.submission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4492,
  serialized_end=4540,
)


_DESCRIBESUBMISSIONOUTPUT = _descriptor.Descriptor(
  name='DescribeSubmissionOutput',
  full_name='eolymp.judge.DescribeSubmissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission', full_name='eolymp.judge.DescribeSubmissionOutput.submission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4542,
  serialized_end=4614,
)


_RETESTSUBMISSIONINPUT = _descriptor.Descriptor(
  name='RetestSubmissionInput',
  full_name='eolymp.judge.RetestSubmissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.judge.RetestSubmissionInput.submission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4616,
  serialized_end=4662,
)


_RETESTSUBMISSIONOUTPUT = _descriptor.Descriptor(
  name='RetestSubmissionOutput',
  full_name='eolymp.judge.RetestSubmissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4664,
  serialized_end=4688,
)


_CREATETICKETINPUT = _descriptor.Descriptor(
  name='CreateTicketInput',
  full_name='eolymp.judge.CreateTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.CreateTicketInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject', full_name='eolymp.judge.CreateTicketInput.subject', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='eolymp.judge.CreateTicketInput.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4690,
  serialized_end=4763,
)


_CREATETICKETOUTPUT = _descriptor.Descriptor(
  name='CreateTicketOutput',
  full_name='eolymp.judge.CreateTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.CreateTicketOutput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4765,
  serialized_end=4804,
)


_CLOSETICKETINPUT = _descriptor.Descriptor(
  name='CloseTicketInput',
  full_name='eolymp.judge.CloseTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.CloseTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4806,
  serialized_end=4843,
)


_CLOSETICKETOUTPUT = _descriptor.Descriptor(
  name='CloseTicketOutput',
  full_name='eolymp.judge.CloseTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4845,
  serialized_end=4864,
)


_OPENTICKETINPUT = _descriptor.Descriptor(
  name='OpenTicketInput',
  full_name='eolymp.judge.OpenTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.OpenTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4866,
  serialized_end=4902,
)


_OPENTICKETOUTPUT = _descriptor.Descriptor(
  name='OpenTicketOutput',
  full_name='eolymp.judge.OpenTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4904,
  serialized_end=4922,
)


_READTICKETINPUT = _descriptor.Descriptor(
  name='ReadTicketInput',
  full_name='eolymp.judge.ReadTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.ReadTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4924,
  serialized_end=4960,
)


_READTICKETOUTPUT = _descriptor.Descriptor(
  name='ReadTicketOutput',
  full_name='eolymp.judge.ReadTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4962,
  serialized_end=4980,
)


_DELETETICKETINPUT = _descriptor.Descriptor(
  name='DeleteTicketInput',
  full_name='eolymp.judge.DeleteTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.DeleteTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4982,
  serialized_end=5020,
)


_DELETETICKETOUTPUT = _descriptor.Descriptor(
  name='DeleteTicketOutput',
  full_name='eolymp.judge.DeleteTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5022,
  serialized_end=5042,
)


_DESCRIBETICKETINPUT = _descriptor.Descriptor(
  name='DescribeTicketInput',
  full_name='eolymp.judge.DescribeTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.DescribeTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5044,
  serialized_end=5084,
)


_DESCRIBETICKETOUTPUT = _descriptor.Descriptor(
  name='DescribeTicketOutput',
  full_name='eolymp.judge.DescribeTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='eolymp.judge.DescribeTicketOutput.ticket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5086,
  serialized_end=5146,
)


_LISTTICKETSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.judge.ListTicketsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.ListTicketsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ListTicketsInput.Filter.contest_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.ListTicketsInput.Filter.participant_id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_read', full_name='eolymp.judge.ListTicketsInput.Filter.is_read', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='needs_reply', full_name='eolymp.judge.ListTicketsInput.Filter.needs_reply', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_open', full_name='eolymp.judge.ListTicketsInput.Filter.is_open', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='own', full_name='eolymp.judge.ListTicketsInput.Filter.own', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5256,
  serialized_end=5620,
)

_LISTTICKETSINPUT = _descriptor.Descriptor(
  name='ListTicketsInput',
  full_name='eolymp.judge.ListTicketsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListTicketsInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListTicketsInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.judge.ListTicketsInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTTICKETSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5149,
  serialized_end=5620,
)


_LISTTICKETSOUTPUT = _descriptor.Descriptor(
  name='ListTicketsOutput',
  full_name='eolymp.judge.ListTicketsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListTicketsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListTicketsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5622,
  serialized_end=5693,
)


_REPLYTICKETINPUT = _descriptor.Descriptor(
  name='ReplyTicketInput',
  full_name='eolymp.judge.ReplyTicketInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.ReplyTicketInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='eolymp.judge.ReplyTicketInput.message', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='eolymp.judge.ReplyTicketInput.close', index=2,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5695,
  serialized_end=5764,
)


_REPLYTICKETOUTPUT = _descriptor.Descriptor(
  name='ReplyTicketOutput',
  full_name='eolymp.judge.ReplyTicketOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reply_id', full_name='eolymp.judge.ReplyTicketOutput.reply_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5766,
  serialized_end=5803,
)


_LISTREPLIESINPUT = _descriptor.Descriptor(
  name='ListRepliesInput',
  full_name='eolymp.judge.ListRepliesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_id', full_name='eolymp.judge.ListRepliesInput.ticket_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.judge.ListRepliesInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.judge.ListRepliesInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5805,
  serialized_end=5872,
)


_LISTREPLIESOUTPUT = _descriptor.Descriptor(
  name='ListRepliesOutput',
  full_name='eolymp.judge.ListRepliesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.judge.ListRepliesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.judge.ListRepliesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5874,
  serialized_end=5944,
)


_DELETEREPLYINPUT = _descriptor.Descriptor(
  name='DeleteReplyInput',
  full_name='eolymp.judge.DeleteReplyInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reply_id', full_name='eolymp.judge.DeleteReplyInput.reply_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5946,
  serialized_end=5982,
)


_DELETEREPLYOUTPUT = _descriptor.Descriptor(
  name='DeleteReplyOutput',
  full_name='eolymp.judge.DeleteReplyOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5984,
  serialized_end=6003,
)


_UPDATEREPLYINPUT = _descriptor.Descriptor(
  name='UpdateReplyInput',
  full_name='eolymp.judge.UpdateReplyInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reply_id', full_name='eolymp.judge.UpdateReplyInput.reply_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='eolymp.judge.UpdateReplyInput.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6005,
  serialized_end=6058,
)


_UPDATEREPLYOUTPUT = _descriptor.Descriptor(
  name='UpdateReplyOutput',
  full_name='eolymp.judge.UpdateReplyOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6060,
  serialized_end=6079,
)


_CONFIGUREREGISTRATIONFORMINPUT = _descriptor.Descriptor(
  name='ConfigureRegistrationFormInput',
  full_name='eolymp.judge.ConfigureRegistrationFormInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.ConfigureRegistrationFormInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='form', full_name='eolymp.judge.ConfigureRegistrationFormInput.form', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6081,
  serialized_end=6167,
)


_CONFIGUREREGISTRATIONFORMOUTPUT = _descriptor.Descriptor(
  name='ConfigureRegistrationFormOutput',
  full_name='eolymp.judge.ConfigureRegistrationFormOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6169,
  serialized_end=6202,
)


_DESCRIBEREGISTRATIONFORMINPUT = _descriptor.Descriptor(
  name='DescribeRegistrationFormInput',
  full_name='eolymp.judge.DescribeRegistrationFormInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.DescribeRegistrationFormInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6204,
  serialized_end=6255,
)


_DESCRIBEREGISTRATIONFORMOUTPUT = _descriptor.Descriptor(
  name='DescribeRegistrationFormOutput',
  full_name='eolymp.judge.DescribeRegistrationFormOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='form', full_name='eolymp.judge.DescribeRegistrationFormOutput.form', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6257,
  serialized_end=6323,
)


_SUBMITREGISTRATIONINPUT = _descriptor.Descriptor(
  name='SubmitRegistrationInput',
  full_name='eolymp.judge.SubmitRegistrationInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.SubmitRegistrationInput.contest_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='registration', full_name='eolymp.judge.SubmitRegistrationInput.registration', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6325,
  serialized_end=6420,
)


_SUBMITREGISTRATIONOUTPUT = _descriptor.Descriptor(
  name='SubmitRegistrationOutput',
  full_name='eolymp.judge.SubmitRegistrationOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6422,
  serialized_end=6448,
)


_DESCRIBEREGISTRATIONINPUT = _descriptor.Descriptor(
  name='DescribeRegistrationInput',
  full_name='eolymp.judge.DescribeRegistrationInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.DescribeRegistrationInput.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6450,
  serialized_end=6501,
)


_DESCRIBEREGISTRATIONOUTPUT = _descriptor.Descriptor(
  name='DescribeRegistrationOutput',
  full_name='eolymp.judge.DescribeRegistrationOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registration', full_name='eolymp.judge.DescribeRegistrationOutput.registration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6503,
  serialized_end=6581,
)

_CREATECONTESTINPUT.fields_by_name['contest'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST
_UPDATECONTESTINPUT.fields_by_name['contest'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST
_DESCRIBECONTESTOUTPUT.fields_by_name['contest'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST
_LOOKUPCONTESTOUTPUT.fields_by_name['contest'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST
_LISTCONTESTSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTCONTESTSINPUT_FILTER.fields_by_name['own'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTCONTESTSINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTCONTESTSINPUT_FILTER.fields_by_name['starts_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTCONTESTSINPUT_FILTER.fields_by_name['ends_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTCONTESTSINPUT_FILTER.fields_by_name['public'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTCONTESTSINPUT_FILTER.containing_type = _LISTCONTESTSINPUT
_LISTCONTESTSINPUT.fields_by_name['filters'].message_type = _LISTCONTESTSINPUT_FILTER
_LISTCONTESTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_contest__pb2._CONTEST
_CREATEPROBLEMINPUT.fields_by_name['problem'].message_type = eolymp_dot_judge_dot_problem__pb2._PROBLEM
_LISTPROBLEMSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_problem__pb2._PROBLEM
_DESCRIBEPROBLEMOUTPUT.fields_by_name['problem'].message_type = eolymp_dot_judge_dot_problem__pb2._PROBLEM
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['user_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['status'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['score'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONFLOAT
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['penalty'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONFLOAT
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['started_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTPARTICIPANTSINPUT_FILTER.fields_by_name['complete_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTPARTICIPANTSINPUT_FILTER.containing_type = _LISTPARTICIPANTSINPUT
_LISTPARTICIPANTSINPUT.fields_by_name['filters'].message_type = _LISTPARTICIPANTSINPUT_FILTER
_LISTPARTICIPANTSINPUT.fields_by_name['sort'].enum_type = _LISTPARTICIPANTSINPUT_SORTABLE
_LISTPARTICIPANTSINPUT.fields_by_name['order'].enum_type = eolymp_dot_wellknown_dot_direction__pb2._DIRECTION
_LISTPARTICIPANTSINPUT_SORTABLE.containing_type = _LISTPARTICIPANTSINPUT
_LISTPARTICIPANTSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_participant__pb2._PARTICIPANT
_INTROSPECTPARTICIPANTOUTPUT.fields_by_name['participant'].message_type = eolymp_dot_judge_dot_participant__pb2._PARTICIPANT
_DESCRIBEPARTICIPANTOUTPUT.fields_by_name['participant'].message_type = eolymp_dot_judge_dot_participant__pb2._PARTICIPANT
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['participant_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['problem_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['status'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['lang'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['score'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONFLOAT
_LISTSUBMISSIONSINPUT_FILTER.fields_by_name['submitted_at'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONTIMESTAMP
_LISTSUBMISSIONSINPUT_FILTER.containing_type = _LISTSUBMISSIONSINPUT
_LISTSUBMISSIONSINPUT.fields_by_name['filters'].message_type = _LISTSUBMISSIONSINPUT_FILTER
_LISTSUBMISSIONSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_submission__pb2._SUBMISSION
_DESCRIBESUBMISSIONOUTPUT.fields_by_name['submission'].message_type = eolymp_dot_judge_dot_submission__pb2._SUBMISSION
_DESCRIBETICKETOUTPUT.fields_by_name['ticket'].message_type = eolymp_dot_judge_dot_ticket__pb2._TICKET
_LISTTICKETSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTTICKETSINPUT_FILTER.fields_by_name['contest_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTTICKETSINPUT_FILTER.fields_by_name['participant_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTTICKETSINPUT_FILTER.fields_by_name['is_read'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTTICKETSINPUT_FILTER.fields_by_name['needs_reply'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTTICKETSINPUT_FILTER.fields_by_name['is_open'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTTICKETSINPUT_FILTER.fields_by_name['own'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTTICKETSINPUT_FILTER.containing_type = _LISTTICKETSINPUT
_LISTTICKETSINPUT.fields_by_name['filters'].message_type = _LISTTICKETSINPUT_FILTER
_LISTTICKETSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_ticket__pb2._TICKET
_LISTREPLIESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_judge_dot_reply__pb2._REPLY
_CONFIGUREREGISTRATIONFORMINPUT.fields_by_name['form'].message_type = eolymp_dot_judge_dot_form__pb2._FORM
_DESCRIBEREGISTRATIONFORMOUTPUT.fields_by_name['form'].message_type = eolymp_dot_judge_dot_form__pb2._FORM
_SUBMITREGISTRATIONINPUT.fields_by_name['registration'].message_type = eolymp_dot_judge_dot_form__pb2._REGISTRATION
_DESCRIBEREGISTRATIONOUTPUT.fields_by_name['registration'].message_type = eolymp_dot_judge_dot_form__pb2._REGISTRATION
DESCRIPTOR.message_types_by_name['CreateContestInput'] = _CREATECONTESTINPUT
DESCRIPTOR.message_types_by_name['CreateContestOutput'] = _CREATECONTESTOUTPUT
DESCRIPTOR.message_types_by_name['DeleteContestInput'] = _DELETECONTESTINPUT
DESCRIPTOR.message_types_by_name['DeleteContestOutput'] = _DELETECONTESTOUTPUT
DESCRIPTOR.message_types_by_name['UpdateContestInput'] = _UPDATECONTESTINPUT
DESCRIPTOR.message_types_by_name['UpdateContestOutput'] = _UPDATECONTESTOUTPUT
DESCRIPTOR.message_types_by_name['DescribeContestInput'] = _DESCRIBECONTESTINPUT
DESCRIPTOR.message_types_by_name['DescribeContestOutput'] = _DESCRIBECONTESTOUTPUT
DESCRIPTOR.message_types_by_name['LookupContestInput'] = _LOOKUPCONTESTINPUT
DESCRIPTOR.message_types_by_name['LookupContestOutput'] = _LOOKUPCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['ListContestsInput'] = _LISTCONTESTSINPUT
DESCRIPTOR.message_types_by_name['ListContestsOutput'] = _LISTCONTESTSOUTPUT
DESCRIPTOR.message_types_by_name['OpenContestInput'] = _OPENCONTESTINPUT
DESCRIPTOR.message_types_by_name['OpenContestOutput'] = _OPENCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['CloseContestInput'] = _CLOSECONTESTINPUT
DESCRIPTOR.message_types_by_name['CloseContestOutput'] = _CLOSECONTESTOUTPUT
DESCRIPTOR.message_types_by_name['StartContestInput'] = _STARTCONTESTINPUT
DESCRIPTOR.message_types_by_name['StartContestOutput'] = _STARTCONTESTOUTPUT
DESCRIPTOR.message_types_by_name['CreateProblemInput'] = _CREATEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['CreateProblemOutput'] = _CREATEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['ImportProblemInput'] = _IMPORTPROBLEMINPUT
DESCRIPTOR.message_types_by_name['ImportProblemOutput'] = _IMPORTPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['SyncProblemInput'] = _SYNCPROBLEMINPUT
DESCRIPTOR.message_types_by_name['SyncProblemOutput'] = _SYNCPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['DeleteProblemInput'] = _DELETEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['DeleteProblemOutput'] = _DELETEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['RetestProblemInput'] = _RETESTPROBLEMINPUT
DESCRIPTOR.message_types_by_name['RetestProblemOutput'] = _RETESTPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['ListProblemsInput'] = _LISTPROBLEMSINPUT
DESCRIPTOR.message_types_by_name['ListProblemsOutput'] = _LISTPROBLEMSOUTPUT
DESCRIPTOR.message_types_by_name['DescribeProblemInput'] = _DESCRIBEPROBLEMINPUT
DESCRIPTOR.message_types_by_name['DescribeProblemOutput'] = _DESCRIBEPROBLEMOUTPUT
DESCRIPTOR.message_types_by_name['AddParticipantInput'] = _ADDPARTICIPANTINPUT
DESCRIPTOR.message_types_by_name['AddParticipantOutput'] = _ADDPARTICIPANTOUTPUT
DESCRIPTOR.message_types_by_name['RemoveParticipantInput'] = _REMOVEPARTICIPANTINPUT
DESCRIPTOR.message_types_by_name['RemoveParticipantOutput'] = _REMOVEPARTICIPANTOUTPUT
DESCRIPTOR.message_types_by_name['ListParticipantsInput'] = _LISTPARTICIPANTSINPUT
DESCRIPTOR.message_types_by_name['ListParticipantsOutput'] = _LISTPARTICIPANTSOUTPUT
DESCRIPTOR.message_types_by_name['IntrospectParticipantInput'] = _INTROSPECTPARTICIPANTINPUT
DESCRIPTOR.message_types_by_name['IntrospectParticipantOutput'] = _INTROSPECTPARTICIPANTOUTPUT
DESCRIPTOR.message_types_by_name['DescribeParticipantInput'] = _DESCRIBEPARTICIPANTINPUT
DESCRIPTOR.message_types_by_name['DescribeParticipantOutput'] = _DESCRIBEPARTICIPANTOUTPUT
DESCRIPTOR.message_types_by_name['CreateSubmissionInput'] = _CREATESUBMISSIONINPUT
DESCRIPTOR.message_types_by_name['CreateSubmissionOutput'] = _CREATESUBMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['ListSubmissionsInput'] = _LISTSUBMISSIONSINPUT
DESCRIPTOR.message_types_by_name['ListSubmissionsOutput'] = _LISTSUBMISSIONSOUTPUT
DESCRIPTOR.message_types_by_name['DescribeSubmissionInput'] = _DESCRIBESUBMISSIONINPUT
DESCRIPTOR.message_types_by_name['DescribeSubmissionOutput'] = _DESCRIBESUBMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['RetestSubmissionInput'] = _RETESTSUBMISSIONINPUT
DESCRIPTOR.message_types_by_name['RetestSubmissionOutput'] = _RETESTSUBMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['CreateTicketInput'] = _CREATETICKETINPUT
DESCRIPTOR.message_types_by_name['CreateTicketOutput'] = _CREATETICKETOUTPUT
DESCRIPTOR.message_types_by_name['CloseTicketInput'] = _CLOSETICKETINPUT
DESCRIPTOR.message_types_by_name['CloseTicketOutput'] = _CLOSETICKETOUTPUT
DESCRIPTOR.message_types_by_name['OpenTicketInput'] = _OPENTICKETINPUT
DESCRIPTOR.message_types_by_name['OpenTicketOutput'] = _OPENTICKETOUTPUT
DESCRIPTOR.message_types_by_name['ReadTicketInput'] = _READTICKETINPUT
DESCRIPTOR.message_types_by_name['ReadTicketOutput'] = _READTICKETOUTPUT
DESCRIPTOR.message_types_by_name['DeleteTicketInput'] = _DELETETICKETINPUT
DESCRIPTOR.message_types_by_name['DeleteTicketOutput'] = _DELETETICKETOUTPUT
DESCRIPTOR.message_types_by_name['DescribeTicketInput'] = _DESCRIBETICKETINPUT
DESCRIPTOR.message_types_by_name['DescribeTicketOutput'] = _DESCRIBETICKETOUTPUT
DESCRIPTOR.message_types_by_name['ListTicketsInput'] = _LISTTICKETSINPUT
DESCRIPTOR.message_types_by_name['ListTicketsOutput'] = _LISTTICKETSOUTPUT
DESCRIPTOR.message_types_by_name['ReplyTicketInput'] = _REPLYTICKETINPUT
DESCRIPTOR.message_types_by_name['ReplyTicketOutput'] = _REPLYTICKETOUTPUT
DESCRIPTOR.message_types_by_name['ListRepliesInput'] = _LISTREPLIESINPUT
DESCRIPTOR.message_types_by_name['ListRepliesOutput'] = _LISTREPLIESOUTPUT
DESCRIPTOR.message_types_by_name['DeleteReplyInput'] = _DELETEREPLYINPUT
DESCRIPTOR.message_types_by_name['DeleteReplyOutput'] = _DELETEREPLYOUTPUT
DESCRIPTOR.message_types_by_name['UpdateReplyInput'] = _UPDATEREPLYINPUT
DESCRIPTOR.message_types_by_name['UpdateReplyOutput'] = _UPDATEREPLYOUTPUT
DESCRIPTOR.message_types_by_name['ConfigureRegistrationFormInput'] = _CONFIGUREREGISTRATIONFORMINPUT
DESCRIPTOR.message_types_by_name['ConfigureRegistrationFormOutput'] = _CONFIGUREREGISTRATIONFORMOUTPUT
DESCRIPTOR.message_types_by_name['DescribeRegistrationFormInput'] = _DESCRIBEREGISTRATIONFORMINPUT
DESCRIPTOR.message_types_by_name['DescribeRegistrationFormOutput'] = _DESCRIBEREGISTRATIONFORMOUTPUT
DESCRIPTOR.message_types_by_name['SubmitRegistrationInput'] = _SUBMITREGISTRATIONINPUT
DESCRIPTOR.message_types_by_name['SubmitRegistrationOutput'] = _SUBMITREGISTRATIONOUTPUT
DESCRIPTOR.message_types_by_name['DescribeRegistrationInput'] = _DESCRIBEREGISTRATIONINPUT
DESCRIPTOR.message_types_by_name['DescribeRegistrationOutput'] = _DESCRIBEREGISTRATIONOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateContestInput = _reflection.GeneratedProtocolMessageType('CreateContestInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateContestInput)
  })
_sym_db.RegisterMessage(CreateContestInput)

CreateContestOutput = _reflection.GeneratedProtocolMessageType('CreateContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateContestOutput)
  })
_sym_db.RegisterMessage(CreateContestOutput)

DeleteContestInput = _reflection.GeneratedProtocolMessageType('DeleteContestInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteContestInput)
  })
_sym_db.RegisterMessage(DeleteContestInput)

DeleteContestOutput = _reflection.GeneratedProtocolMessageType('DeleteContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteContestOutput)
  })
_sym_db.RegisterMessage(DeleteContestOutput)

UpdateContestInput = _reflection.GeneratedProtocolMessageType('UpdateContestInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateContestInput)
  })
_sym_db.RegisterMessage(UpdateContestInput)

UpdateContestOutput = _reflection.GeneratedProtocolMessageType('UpdateContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateContestOutput)
  })
_sym_db.RegisterMessage(UpdateContestOutput)

DescribeContestInput = _reflection.GeneratedProtocolMessageType('DescribeContestInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeContestInput)
  })
_sym_db.RegisterMessage(DescribeContestInput)

DescribeContestOutput = _reflection.GeneratedProtocolMessageType('DescribeContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBECONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeContestOutput)
  })
_sym_db.RegisterMessage(DescribeContestOutput)

LookupContestInput = _reflection.GeneratedProtocolMessageType('LookupContestInput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPCONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.LookupContestInput)
  })
_sym_db.RegisterMessage(LookupContestInput)

LookupContestOutput = _reflection.GeneratedProtocolMessageType('LookupContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPCONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.LookupContestOutput)
  })
_sym_db.RegisterMessage(LookupContestOutput)

ListContestsInput = _reflection.GeneratedProtocolMessageType('ListContestsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTCONTESTSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListContestsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTCONTESTSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListContestsInput)
  })
_sym_db.RegisterMessage(ListContestsInput)
_sym_db.RegisterMessage(ListContestsInput.Filter)

ListContestsOutput = _reflection.GeneratedProtocolMessageType('ListContestsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTESTSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListContestsOutput)
  })
_sym_db.RegisterMessage(ListContestsOutput)

OpenContestInput = _reflection.GeneratedProtocolMessageType('OpenContestInput', (_message.Message,), {
  'DESCRIPTOR' : _OPENCONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.OpenContestInput)
  })
_sym_db.RegisterMessage(OpenContestInput)

OpenContestOutput = _reflection.GeneratedProtocolMessageType('OpenContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _OPENCONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.OpenContestOutput)
  })
_sym_db.RegisterMessage(OpenContestOutput)

CloseContestInput = _reflection.GeneratedProtocolMessageType('CloseContestInput', (_message.Message,), {
  'DESCRIPTOR' : _CLOSECONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CloseContestInput)
  })
_sym_db.RegisterMessage(CloseContestInput)

CloseContestOutput = _reflection.GeneratedProtocolMessageType('CloseContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _CLOSECONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CloseContestOutput)
  })
_sym_db.RegisterMessage(CloseContestOutput)

StartContestInput = _reflection.GeneratedProtocolMessageType('StartContestInput', (_message.Message,), {
  'DESCRIPTOR' : _STARTCONTESTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.StartContestInput)
  })
_sym_db.RegisterMessage(StartContestInput)

StartContestOutput = _reflection.GeneratedProtocolMessageType('StartContestOutput', (_message.Message,), {
  'DESCRIPTOR' : _STARTCONTESTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.StartContestOutput)
  })
_sym_db.RegisterMessage(StartContestOutput)

CreateProblemInput = _reflection.GeneratedProtocolMessageType('CreateProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateProblemInput)
  })
_sym_db.RegisterMessage(CreateProblemInput)

CreateProblemOutput = _reflection.GeneratedProtocolMessageType('CreateProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateProblemOutput)
  })
_sym_db.RegisterMessage(CreateProblemOutput)

ImportProblemInput = _reflection.GeneratedProtocolMessageType('ImportProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ImportProblemInput)
  })
_sym_db.RegisterMessage(ImportProblemInput)

ImportProblemOutput = _reflection.GeneratedProtocolMessageType('ImportProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ImportProblemOutput)
  })
_sym_db.RegisterMessage(ImportProblemOutput)

SyncProblemInput = _reflection.GeneratedProtocolMessageType('SyncProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _SYNCPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.SyncProblemInput)
  })
_sym_db.RegisterMessage(SyncProblemInput)

SyncProblemOutput = _reflection.GeneratedProtocolMessageType('SyncProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _SYNCPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.SyncProblemOutput)
  })
_sym_db.RegisterMessage(SyncProblemOutput)

DeleteProblemInput = _reflection.GeneratedProtocolMessageType('DeleteProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteProblemInput)
  })
_sym_db.RegisterMessage(DeleteProblemInput)

DeleteProblemOutput = _reflection.GeneratedProtocolMessageType('DeleteProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteProblemOutput)
  })
_sym_db.RegisterMessage(DeleteProblemOutput)

RetestProblemInput = _reflection.GeneratedProtocolMessageType('RetestProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _RETESTPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RetestProblemInput)
  })
_sym_db.RegisterMessage(RetestProblemInput)

RetestProblemOutput = _reflection.GeneratedProtocolMessageType('RetestProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _RETESTPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RetestProblemOutput)
  })
_sym_db.RegisterMessage(RetestProblemOutput)

ListProblemsInput = _reflection.GeneratedProtocolMessageType('ListProblemsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROBLEMSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListProblemsInput)
  })
_sym_db.RegisterMessage(ListProblemsInput)

ListProblemsOutput = _reflection.GeneratedProtocolMessageType('ListProblemsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROBLEMSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListProblemsOutput)
  })
_sym_db.RegisterMessage(ListProblemsOutput)

DescribeProblemInput = _reflection.GeneratedProtocolMessageType('DescribeProblemInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPROBLEMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeProblemInput)
  })
_sym_db.RegisterMessage(DescribeProblemInput)

DescribeProblemOutput = _reflection.GeneratedProtocolMessageType('DescribeProblemOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPROBLEMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeProblemOutput)
  })
_sym_db.RegisterMessage(DescribeProblemOutput)

AddParticipantInput = _reflection.GeneratedProtocolMessageType('AddParticipantInput', (_message.Message,), {
  'DESCRIPTOR' : _ADDPARTICIPANTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.AddParticipantInput)
  })
_sym_db.RegisterMessage(AddParticipantInput)

AddParticipantOutput = _reflection.GeneratedProtocolMessageType('AddParticipantOutput', (_message.Message,), {
  'DESCRIPTOR' : _ADDPARTICIPANTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.AddParticipantOutput)
  })
_sym_db.RegisterMessage(AddParticipantOutput)

RemoveParticipantInput = _reflection.GeneratedProtocolMessageType('RemoveParticipantInput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPARTICIPANTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RemoveParticipantInput)
  })
_sym_db.RegisterMessage(RemoveParticipantInput)

RemoveParticipantOutput = _reflection.GeneratedProtocolMessageType('RemoveParticipantOutput', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPARTICIPANTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RemoveParticipantOutput)
  })
_sym_db.RegisterMessage(RemoveParticipantOutput)

ListParticipantsInput = _reflection.GeneratedProtocolMessageType('ListParticipantsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTPARTICIPANTSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListParticipantsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTPARTICIPANTSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListParticipantsInput)
  })
_sym_db.RegisterMessage(ListParticipantsInput)
_sym_db.RegisterMessage(ListParticipantsInput.Filter)

ListParticipantsOutput = _reflection.GeneratedProtocolMessageType('ListParticipantsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARTICIPANTSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListParticipantsOutput)
  })
_sym_db.RegisterMessage(ListParticipantsOutput)

IntrospectParticipantInput = _reflection.GeneratedProtocolMessageType('IntrospectParticipantInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTPARTICIPANTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.IntrospectParticipantInput)
  })
_sym_db.RegisterMessage(IntrospectParticipantInput)

IntrospectParticipantOutput = _reflection.GeneratedProtocolMessageType('IntrospectParticipantOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTPARTICIPANTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.IntrospectParticipantOutput)
  })
_sym_db.RegisterMessage(IntrospectParticipantOutput)

DescribeParticipantInput = _reflection.GeneratedProtocolMessageType('DescribeParticipantInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPARTICIPANTINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeParticipantInput)
  })
_sym_db.RegisterMessage(DescribeParticipantInput)

DescribeParticipantOutput = _reflection.GeneratedProtocolMessageType('DescribeParticipantOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPARTICIPANTOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeParticipantOutput)
  })
_sym_db.RegisterMessage(DescribeParticipantOutput)

CreateSubmissionInput = _reflection.GeneratedProtocolMessageType('CreateSubmissionInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBMISSIONINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateSubmissionInput)
  })
_sym_db.RegisterMessage(CreateSubmissionInput)

CreateSubmissionOutput = _reflection.GeneratedProtocolMessageType('CreateSubmissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBMISSIONOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateSubmissionOutput)
  })
_sym_db.RegisterMessage(CreateSubmissionOutput)

ListSubmissionsInput = _reflection.GeneratedProtocolMessageType('ListSubmissionsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSUBMISSIONSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListSubmissionsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSUBMISSIONSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListSubmissionsInput)
  })
_sym_db.RegisterMessage(ListSubmissionsInput)
_sym_db.RegisterMessage(ListSubmissionsInput.Filter)

ListSubmissionsOutput = _reflection.GeneratedProtocolMessageType('ListSubmissionsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSUBMISSIONSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListSubmissionsOutput)
  })
_sym_db.RegisterMessage(ListSubmissionsOutput)

DescribeSubmissionInput = _reflection.GeneratedProtocolMessageType('DescribeSubmissionInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESUBMISSIONINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeSubmissionInput)
  })
_sym_db.RegisterMessage(DescribeSubmissionInput)

DescribeSubmissionOutput = _reflection.GeneratedProtocolMessageType('DescribeSubmissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESUBMISSIONOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeSubmissionOutput)
  })
_sym_db.RegisterMessage(DescribeSubmissionOutput)

RetestSubmissionInput = _reflection.GeneratedProtocolMessageType('RetestSubmissionInput', (_message.Message,), {
  'DESCRIPTOR' : _RETESTSUBMISSIONINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RetestSubmissionInput)
  })
_sym_db.RegisterMessage(RetestSubmissionInput)

RetestSubmissionOutput = _reflection.GeneratedProtocolMessageType('RetestSubmissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _RETESTSUBMISSIONOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.RetestSubmissionOutput)
  })
_sym_db.RegisterMessage(RetestSubmissionOutput)

CreateTicketInput = _reflection.GeneratedProtocolMessageType('CreateTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateTicketInput)
  })
_sym_db.RegisterMessage(CreateTicketInput)

CreateTicketOutput = _reflection.GeneratedProtocolMessageType('CreateTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATETICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CreateTicketOutput)
  })
_sym_db.RegisterMessage(CreateTicketOutput)

CloseTicketInput = _reflection.GeneratedProtocolMessageType('CloseTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CloseTicketInput)
  })
_sym_db.RegisterMessage(CloseTicketInput)

CloseTicketOutput = _reflection.GeneratedProtocolMessageType('CloseTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _CLOSETICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.CloseTicketOutput)
  })
_sym_db.RegisterMessage(CloseTicketOutput)

OpenTicketInput = _reflection.GeneratedProtocolMessageType('OpenTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _OPENTICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.OpenTicketInput)
  })
_sym_db.RegisterMessage(OpenTicketInput)

OpenTicketOutput = _reflection.GeneratedProtocolMessageType('OpenTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _OPENTICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.OpenTicketOutput)
  })
_sym_db.RegisterMessage(OpenTicketOutput)

ReadTicketInput = _reflection.GeneratedProtocolMessageType('ReadTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _READTICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ReadTicketInput)
  })
_sym_db.RegisterMessage(ReadTicketInput)

ReadTicketOutput = _reflection.GeneratedProtocolMessageType('ReadTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _READTICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ReadTicketOutput)
  })
_sym_db.RegisterMessage(ReadTicketOutput)

DeleteTicketInput = _reflection.GeneratedProtocolMessageType('DeleteTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETETICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteTicketInput)
  })
_sym_db.RegisterMessage(DeleteTicketInput)

DeleteTicketOutput = _reflection.GeneratedProtocolMessageType('DeleteTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETETICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteTicketOutput)
  })
_sym_db.RegisterMessage(DeleteTicketOutput)

DescribeTicketInput = _reflection.GeneratedProtocolMessageType('DescribeTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeTicketInput)
  })
_sym_db.RegisterMessage(DescribeTicketInput)

DescribeTicketOutput = _reflection.GeneratedProtocolMessageType('DescribeTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBETICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeTicketOutput)
  })
_sym_db.RegisterMessage(DescribeTicketOutput)

ListTicketsInput = _reflection.GeneratedProtocolMessageType('ListTicketsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTTICKETSINPUT_FILTER,
    '__module__' : 'eolymp.judge.judge_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.ListTicketsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTTICKETSINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListTicketsInput)
  })
_sym_db.RegisterMessage(ListTicketsInput)
_sym_db.RegisterMessage(ListTicketsInput.Filter)

ListTicketsOutput = _reflection.GeneratedProtocolMessageType('ListTicketsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTTICKETSOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListTicketsOutput)
  })
_sym_db.RegisterMessage(ListTicketsOutput)

ReplyTicketInput = _reflection.GeneratedProtocolMessageType('ReplyTicketInput', (_message.Message,), {
  'DESCRIPTOR' : _REPLYTICKETINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ReplyTicketInput)
  })
_sym_db.RegisterMessage(ReplyTicketInput)

ReplyTicketOutput = _reflection.GeneratedProtocolMessageType('ReplyTicketOutput', (_message.Message,), {
  'DESCRIPTOR' : _REPLYTICKETOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ReplyTicketOutput)
  })
_sym_db.RegisterMessage(ReplyTicketOutput)

ListRepliesInput = _reflection.GeneratedProtocolMessageType('ListRepliesInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPLIESINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListRepliesInput)
  })
_sym_db.RegisterMessage(ListRepliesInput)

ListRepliesOutput = _reflection.GeneratedProtocolMessageType('ListRepliesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPLIESOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ListRepliesOutput)
  })
_sym_db.RegisterMessage(ListRepliesOutput)

DeleteReplyInput = _reflection.GeneratedProtocolMessageType('DeleteReplyInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPLYINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteReplyInput)
  })
_sym_db.RegisterMessage(DeleteReplyInput)

DeleteReplyOutput = _reflection.GeneratedProtocolMessageType('DeleteReplyOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPLYOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DeleteReplyOutput)
  })
_sym_db.RegisterMessage(DeleteReplyOutput)

UpdateReplyInput = _reflection.GeneratedProtocolMessageType('UpdateReplyInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPLYINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateReplyInput)
  })
_sym_db.RegisterMessage(UpdateReplyInput)

UpdateReplyOutput = _reflection.GeneratedProtocolMessageType('UpdateReplyOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPLYOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.UpdateReplyOutput)
  })
_sym_db.RegisterMessage(UpdateReplyOutput)

ConfigureRegistrationFormInput = _reflection.GeneratedProtocolMessageType('ConfigureRegistrationFormInput', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREREGISTRATIONFORMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ConfigureRegistrationFormInput)
  })
_sym_db.RegisterMessage(ConfigureRegistrationFormInput)

ConfigureRegistrationFormOutput = _reflection.GeneratedProtocolMessageType('ConfigureRegistrationFormOutput', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREREGISTRATIONFORMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.ConfigureRegistrationFormOutput)
  })
_sym_db.RegisterMessage(ConfigureRegistrationFormOutput)

DescribeRegistrationFormInput = _reflection.GeneratedProtocolMessageType('DescribeRegistrationFormInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEREGISTRATIONFORMINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeRegistrationFormInput)
  })
_sym_db.RegisterMessage(DescribeRegistrationFormInput)

DescribeRegistrationFormOutput = _reflection.GeneratedProtocolMessageType('DescribeRegistrationFormOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEREGISTRATIONFORMOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeRegistrationFormOutput)
  })
_sym_db.RegisterMessage(DescribeRegistrationFormOutput)

SubmitRegistrationInput = _reflection.GeneratedProtocolMessageType('SubmitRegistrationInput', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITREGISTRATIONINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.SubmitRegistrationInput)
  })
_sym_db.RegisterMessage(SubmitRegistrationInput)

SubmitRegistrationOutput = _reflection.GeneratedProtocolMessageType('SubmitRegistrationOutput', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITREGISTRATIONOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.SubmitRegistrationOutput)
  })
_sym_db.RegisterMessage(SubmitRegistrationOutput)

DescribeRegistrationInput = _reflection.GeneratedProtocolMessageType('DescribeRegistrationInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEREGISTRATIONINPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeRegistrationInput)
  })
_sym_db.RegisterMessage(DescribeRegistrationInput)

DescribeRegistrationOutput = _reflection.GeneratedProtocolMessageType('DescribeRegistrationOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEREGISTRATIONOUTPUT,
  '__module__' : 'eolymp.judge.judge_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.DescribeRegistrationOutput)
  })
_sym_db.RegisterMessage(DescribeRegistrationOutput)


DESCRIPTOR._options = None

_JUDGE = _descriptor.ServiceDescriptor(
  name='Judge',
  full_name='eolymp.judge.Judge',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=6584,
  serialized_end=14045,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateContest',
    full_name='eolymp.judge.Judge.CreateContest',
    index=0,
    containing_service=None,
    input_type=_CREATECONTESTINPUT,
    output_type=_CREATECONTESTOUTPUT,
    serialized_options=b'\202\323\344\223\002H\"\'/twirp/eolymp.judge.Judge/CreateContest:\001*Z\032\"\017/judge/contests:\007contest',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteContest',
    full_name='eolymp.judge.Judge.DeleteContest',
    index=1,
    containing_service=None,
    input_type=_DELETECONTESTINPUT,
    output_type=_DELETECONTESTOUTPUT,
    serialized_options=b'\202\323\344\223\002L\"\'/twirp/eolymp.judge.Judge/DeleteContest:\001*Z\036*\034/judge/contests/{contest_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateContest',
    full_name='eolymp.judge.Judge.UpdateContest',
    index=2,
    containing_service=None,
    input_type=_UPDATECONTESTINPUT,
    output_type=_UPDATECONTESTOUTPUT,
    serialized_options=b'\202\323\344\223\002U\"\'/twirp/eolymp.judge.Judge/UpdateContest:\001*Z\'\032\034/judge/contests/{contest_id}:\007contest',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LookupContest',
    full_name='eolymp.judge.Judge.LookupContest',
    index=3,
    containing_service=None,
    input_type=_LOOKUPCONTESTINPUT,
    output_type=_LOOKUPCONTESTOUTPUT,
    serialized_options=b'\202\323\344\223\002F\"\'/twirp/eolymp.judge.Judge/LookupContest:\001*Z\030\022\023/judge/lookup/{key}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeContest',
    full_name='eolymp.judge.Judge.DescribeContest',
    index=4,
    containing_service=None,
    input_type=_DESCRIBECONTESTINPUT,
    output_type=_DESCRIBECONTESTOUTPUT,
    serialized_options=b'\202\323\344\223\002W\")/twirp/eolymp.judge.Judge/DescribeContest:\001*Z\'\022\034/judge/contests/{contest_id}b\007contest',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListContests',
    full_name='eolymp.judge.Judge.ListContests',
    index=5,
    containing_service=None,
    input_type=_LISTCONTESTSINPUT,
    output_type=_LISTCONTESTSOUTPUT,
    serialized_options=b'\202\323\344\223\002>\"&/twirp/eolymp.judge.Judge/ListContests:\001*Z\021\022\017/judge/contests',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OpenContest',
    full_name='eolymp.judge.Judge.OpenContest',
    index=6,
    containing_service=None,
    input_type=_OPENCONTESTINPUT,
    output_type=_OPENCONTESTOUTPUT,
    serialized_options=b'\202\323\344\223\002O\"%/twirp/eolymp.judge.Judge/OpenContest:\001*Z#\"!/judge/contests/{contest_id}/open',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseContest',
    full_name='eolymp.judge.Judge.CloseContest',
    index=7,
    containing_service=None,
    input_type=_CLOSECONTESTINPUT,
    output_type=_CLOSECONTESTOUTPUT,
    serialized_options=b'\202\323\344\223\002Q\"&/twirp/eolymp.judge.Judge/CloseContest:\001*Z$\"\"/judge/contests/{contest_id}/close',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfigureRegistrationForm',
    full_name='eolymp.judge.Judge.ConfigureRegistrationForm',
    index=8,
    containing_service=None,
    input_type=_CONFIGUREREGISTRATIONFORMINPUT,
    output_type=_CONFIGUREREGISTRATIONFORMOUTPUT,
    serialized_options=b'\202\323\344\223\002j\"3/twirp/eolymp.judge.Judge/ConfigureRegistrationForm:\001*Z0\"./judge/contests/{contest_id}/registration-form',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeRegistrationForm',
    full_name='eolymp.judge.Judge.DescribeRegistrationForm',
    index=9,
    containing_service=None,
    input_type=_DESCRIBEREGISTRATIONFORMINPUT,
    output_type=_DESCRIBEREGISTRATIONFORMOUTPUT,
    serialized_options=b'\202\323\344\223\002o\"2/twirp/eolymp.judge.Judge/DescribeRegistrationForm:\001*Z6\022./judge/contests/{contest_id}/registration-formb\004form',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitRegistration',
    full_name='eolymp.judge.Judge.SubmitRegistration',
    index=10,
    containing_service=None,
    input_type=_SUBMITREGISTRATIONINPUT,
    output_type=_SUBMITREGISTRATIONOUTPUT,
    serialized_options=b'\202\323\344\223\002Z\",/twirp/eolymp.judge.Judge/SubmitRegistration:\001*Z\'\"%/judge/contests/{contest_id}/register',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeRegistration',
    full_name='eolymp.judge.Judge.DescribeRegistration',
    index=11,
    containing_service=None,
    input_type=_DESCRIBEREGISTRATIONINPUT,
    output_type=_DESCRIBEREGISTRATIONOUTPUT,
    serialized_options=b'\202\323\344\223\002h\"./twirp/eolymp.judge.Judge/DescribeRegistration:\001*Z3\0221/judge/participants/{participant_id}/registration',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateProblem',
    full_name='eolymp.judge.Judge.CreateProblem',
    index=12,
    containing_service=None,
    input_type=_CREATEPROBLEMINPUT,
    output_type=_CREATEPROBLEMOUTPUT,
    serialized_options=b'\202\323\344\223\002^\"\'/twirp/eolymp.judge.Judge/CreateProblem:\001*Z0\"%/judge/contests/{contest_id}/problems:\007problem',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ImportProblem',
    full_name='eolymp.judge.Judge.ImportProblem',
    index=13,
    containing_service=None,
    input_type=_IMPORTPROBLEMINPUT,
    output_type=_IMPORTPROBLEMOUTPUT,
    serialized_options=b'\202\323\344\223\002[\"\'/twirp/eolymp.judge.Judge/ImportProblem:\001*Z-\"+/judge/contests/{contest_id}/import/problem',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SyncProblem',
    full_name='eolymp.judge.Judge.SyncProblem',
    index=14,
    containing_service=None,
    input_type=_SYNCPROBLEMINPUT,
    output_type=_SYNCPROBLEMOUTPUT,
    serialized_options=b'\202\323\344\223\002O\"%/twirp/eolymp.judge.Judge/SyncProblem:\001*Z#\"!/judge/problems/{problem_id}/sync',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListProblems',
    full_name='eolymp.judge.Judge.ListProblems',
    index=15,
    containing_service=None,
    input_type=_LISTPROBLEMSINPUT,
    output_type=_LISTPROBLEMSOUTPUT,
    serialized_options=b'\202\323\344\223\002T\"&/twirp/eolymp.judge.Judge/ListProblems:\001*Z\'\022%/judge/contests/{contest_id}/problems',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeProblem',
    full_name='eolymp.judge.Judge.DescribeProblem',
    index=16,
    containing_service=None,
    input_type=_DESCRIBEPROBLEMINPUT,
    output_type=_DESCRIBEPROBLEMOUTPUT,
    serialized_options=b'\202\323\344\223\002N\")/twirp/eolymp.judge.Judge/DescribeProblem:\001*Z\036\022\034/judge/problems/{problem_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProblem',
    full_name='eolymp.judge.Judge.DeleteProblem',
    index=17,
    containing_service=None,
    input_type=_DELETEPROBLEMINPUT,
    output_type=_DELETEPROBLEMOUTPUT,
    serialized_options=b'\202\323\344\223\002L\"\'/twirp/eolymp.judge.Judge/DeleteProblem:\001*Z\036*\034/judge/problems/{problem_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetestProblem',
    full_name='eolymp.judge.Judge.RetestProblem',
    index=18,
    containing_service=None,
    input_type=_RETESTPROBLEMINPUT,
    output_type=_RETESTPROBLEMOUTPUT,
    serialized_options=b'\202\323\344\223\002V\"\'/twirp/eolymp.judge.Judge/RetestProblem:\001*Z(\022#/judge/problems/{problem_id}/retestb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddParticipant',
    full_name='eolymp.judge.Judge.AddParticipant',
    index=19,
    containing_service=None,
    input_type=_ADDPARTICIPANTINPUT,
    output_type=_ADDPARTICIPANTOUTPUT,
    serialized_options=b'\202\323\344\223\002]\"(/twirp/eolymp.judge.Judge/AddParticipant:\001*Z.\")/judge/contests/{contest_id}/participants:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveParticipant',
    full_name='eolymp.judge.Judge.RemoveParticipant',
    index=20,
    containing_service=None,
    input_type=_REMOVEPARTICIPANTINPUT,
    output_type=_REMOVEPARTICIPANTOUTPUT,
    serialized_options=b'\202\323\344\223\002X\"+/twirp/eolymp.judge.Judge/RemoveParticipant:\001*Z&*$/judge/participants/{participant_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListParticipants',
    full_name='eolymp.judge.Judge.ListParticipants',
    index=21,
    containing_service=None,
    input_type=_LISTPARTICIPANTSINPUT,
    output_type=_LISTPARTICIPANTSOUTPUT,
    serialized_options=b'\202\323\344\223\002\\\"*/twirp/eolymp.judge.Judge/ListParticipants:\001*Z+\022)/judge/contests/{contest_id}/participants',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeParticipant',
    full_name='eolymp.judge.Judge.DescribeParticipant',
    index=22,
    containing_service=None,
    input_type=_DESCRIBEPARTICIPANTINPUT,
    output_type=_DESCRIBEPARTICIPANTOUTPUT,
    serialized_options=b'\202\323\344\223\002g\"-/twirp/eolymp.judge.Judge/DescribeParticipant:\001*Z3\022$/judge/participants/{participant_id}b\013participant',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectParticipant',
    full_name='eolymp.judge.Judge.IntrospectParticipant',
    index=23,
    containing_service=None,
    input_type=_INTROSPECTPARTICIPANTINPUT,
    output_type=_INTROSPECTPARTICIPANTOUTPUT,
    serialized_options=b'\202\323\344\223\002l\"//twirp/eolymp.judge.Judge/IntrospectParticipant:\001*Z6\022\'/judge/contests/{contest_id}/introspectb\013participant',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartContest',
    full_name='eolymp.judge.Judge.StartContest',
    index=24,
    containing_service=None,
    input_type=_STARTCONTESTINPUT,
    output_type=_STARTCONTESTOUTPUT,
    serialized_options=b'\202\323\344\223\002Q\"&/twirp/eolymp.judge.Judge/StartContest:\001*Z$\"\"/judge/contests/{contest_id}/start',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateSubmission',
    full_name='eolymp.judge.Judge.CreateSubmission',
    index=25,
    containing_service=None,
    input_type=_CREATESUBMISSIONINPUT,
    output_type=_CREATESUBMISSIONOUTPUT,
    serialized_options=b'\202\323\344\223\002^\"*/twirp/eolymp.judge.Judge/CreateSubmission:\001*Z-\"(/judge/problems/{problem_id}/submissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSubmissions',
    full_name='eolymp.judge.Judge.ListSubmissions',
    index=26,
    containing_service=None,
    input_type=_LISTSUBMISSIONSINPUT,
    output_type=_LISTSUBMISSIONSOUTPUT,
    serialized_options=b'\202\323\344\223\002\272\001\")/twirp/eolymp.judge.Judge/ListSubmissions:\001*Z*\022(/judge/contests/{contest_id}/submissionsZ*\022(/judge/problems/{problem_id}/submissionsZ2\0220/judge/participants/{participant_id}/submissions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeSubmission',
    full_name='eolymp.judge.Judge.DescribeSubmission',
    index=27,
    containing_service=None,
    input_type=_DESCRIBESUBMISSIONINPUT,
    output_type=_DESCRIBESUBMISSIONOUTPUT,
    serialized_options=b'\202\323\344\223\002c\",/twirp/eolymp.judge.Judge/DescribeSubmission:\001*Z0\022\"/judge/submissions/{submission_id}b\nsubmission',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetestSubmission',
    full_name='eolymp.judge.Judge.RetestSubmission',
    index=28,
    containing_service=None,
    input_type=_RETESTSUBMISSIONINPUT,
    output_type=_RETESTSUBMISSIONOUTPUT,
    serialized_options=b'\202\323\344\223\002_\"*/twirp/eolymp.judge.Judge/RetestSubmission:\001*Z.\022)/judge/submissions/{submission_id}/retestb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTicket',
    full_name='eolymp.judge.Judge.CreateTicket',
    index=29,
    containing_service=None,
    input_type=_CREATETICKETINPUT,
    output_type=_CREATETICKETOUTPUT,
    serialized_options=b'\202\323\344\223\002V\"&/twirp/eolymp.judge.Judge/CreateTicket:\001*Z)\"$/judge/contests/{contest_id}/ticketsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseTicket',
    full_name='eolymp.judge.Judge.CloseTicket',
    index=30,
    containing_service=None,
    input_type=_CLOSETICKETINPUT,
    output_type=_CLOSETICKETOUTPUT,
    serialized_options=b'\202\323\344\223\002Q\"%/twirp/eolymp.judge.Judge/CloseTicket:\001*Z%\" /judge/tickets/{ticket_id}/closeb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OpenTicket',
    full_name='eolymp.judge.Judge.OpenTicket',
    index=31,
    containing_service=None,
    input_type=_OPENTICKETINPUT,
    output_type=_OPENTICKETOUTPUT,
    serialized_options=b'\202\323\344\223\002O\"$/twirp/eolymp.judge.Judge/OpenTicket:\001*Z$\"\037/judge/tickets/{ticket_id}/openb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadTicket',
    full_name='eolymp.judge.Judge.ReadTicket',
    index=32,
    containing_service=None,
    input_type=_READTICKETINPUT,
    output_type=_READTICKETOUTPUT,
    serialized_options=b'\202\323\344\223\002O\"$/twirp/eolymp.judge.Judge/ReadTicket:\001*Z$\"\037/judge/tickets/{ticket_id}/readb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTicket',
    full_name='eolymp.judge.Judge.DeleteTicket',
    index=33,
    containing_service=None,
    input_type=_DELETETICKETINPUT,
    output_type=_DELETETICKETOUTPUT,
    serialized_options=b'\202\323\344\223\002L\"&/twirp/eolymp.judge.Judge/DeleteTicket:\001*Z\037*\032/judge/tickets/{ticket_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeTicket',
    full_name='eolymp.judge.Judge.DescribeTicket',
    index=34,
    containing_service=None,
    input_type=_DESCRIBETICKETINPUT,
    output_type=_DESCRIBETICKETOUTPUT,
    serialized_options=b'\202\323\344\223\002S\"(/twirp/eolymp.judge.Judge/DescribeTicket:\001*Z$\022\032/judge/tickets/{ticket_id}b\006ticket',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTickets',
    full_name='eolymp.judge.Judge.ListTickets',
    index=35,
    containing_service=None,
    input_type=_LISTTICKETSINPUT,
    output_type=_LISTTICKETSOUTPUT,
    serialized_options=b'\202\323\344\223\002?\"%/twirp/eolymp.judge.Judge/ListTickets:\001*Z\023\022\016/judge/ticketsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReplyTicket',
    full_name='eolymp.judge.Judge.ReplyTicket',
    index=36,
    containing_service=None,
    input_type=_REPLYTICKETINPUT,
    output_type=_REPLYTICKETOUTPUT,
    serialized_options=b'\202\323\344\223\002S\"%/twirp/eolymp.judge.Judge/ReplyTicket:\001*Z\'\"\"/judge/tickets/{ticket_id}/repliesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListReplies',
    full_name='eolymp.judge.Judge.ListReplies',
    index=37,
    containing_service=None,
    input_type=_LISTREPLIESINPUT,
    output_type=_LISTREPLIESOUTPUT,
    serialized_options=b'\202\323\344\223\002S\"%/twirp/eolymp.judge.Judge/ListReplies:\001*Z\'\022\"/judge/tickets/{ticket_id}/repliesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteReply',
    full_name='eolymp.judge.Judge.DeleteReply',
    index=38,
    containing_service=None,
    input_type=_DELETEREPLYINPUT,
    output_type=_DELETEREPLYOUTPUT,
    serialized_options=b'\202\323\344\223\002J\"%/twirp/eolymp.judge.Judge/DeleteReply:\001*Z\036*\031/judge/replies/{reply_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateReply',
    full_name='eolymp.judge.Judge.UpdateReply',
    index=39,
    containing_service=None,
    input_type=_UPDATEREPLYINPUT,
    output_type=_UPDATEREPLYOUTPUT,
    serialized_options=b'\202\323\344\223\002J\"%/twirp/eolymp.judge.Judge/UpdateReply:\001*Z\036\"\031/judge/replies/{reply_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JUDGE)

DESCRIPTOR.services_by_name['Judge'] = _JUDGE

# @@protoc_insertion_point(module_scope)
